@@ -4,8 +4,10 @@ from rucio_jupyterlab.rucio import RucioAPIFactory
 from .instances import InstancesHandler
 from .auth_config import AuthConfigHandler
 from .did_browser import DIDBrowserHandler
+from .did_search import DIDSearchHandler
 from .did_details import DIDDetailsHandler
 from .did_make_available import DIDMakeAvailableHandler
+from .file_browser import FileBrowserHandler
 
 
 def setup_handlers(web_app):  # pragma: no cover
@@ -24,7 +26,8 @@ def setup_handlers(web_app):  # pragma: no cover
         (url_path_join(base_path, 'auth'), AuthConfigHandler, handler_params),
         (url_path_join(base_path, 'files'), DIDBrowserHandler, handler_params),
         (url_path_join(base_path, 'did'), DIDDetailsHandler, handler_params),
-        (url_path_join(base_path, 'did', 'make-available'),
-         DIDMakeAvailableHandler, handler_params),
+        (url_path_join(base_path, 'did-search'), DIDSearchHandler, handler_params),
+        (url_path_join(base_path, 'did', 'make-available'), DIDMakeAvailableHandler, handler_params),
+        (url_path_join(base_path, 'file-browser'), FileBrowserHandler, handler_params),
     ]
     web_app.add_handlers(host_pattern, handlers)
