@@ -1,6 +1,7 @@
 import json
 import tornado
 from rucio_jupyterlab.db import get_db
+from rucio_jupyterlab.rucio import RucioAPI
 from .base import RucioAPIHandler
 
 
@@ -31,4 +32,6 @@ class InstancesHandler(RucioAPIHandler):
         db.set_active_instance(picked_instance)
         db.set_active_auth_method(picked_auth_type)
 
+        RucioAPI.clear_auth_token_cache()
+
         self.finish(json.dumps({'success': True}))
