@@ -1,18 +1,18 @@
 import React, { useEffect, useMemo } from 'react';
 import { createUseStyles } from 'react-jss';
 import { useStoreState } from 'pullstate';
-import { NotebookDIDAttachment, FileStatus, ContainerStatus, ResolveStatus } from '../../types';
+import { NotebookDIDAttachment, FileStatus, CollectionStatus, ResolveStatus } from '../../types';
 import { Spinning } from '../Spinning';
 import { WithRequestAPIProps, withRequestAPI } from '../../utils/Actions';
 import { UIStore } from '../../stores/UIStore';
-import { computeContainerState } from '../../utils/Helpers';
+import { computeCollectionState } from '../../utils/Helpers';
 import { ExtensionStore } from '../../stores/ExtensionStore';
 
 const useStyles = createUseStyles({
   listItemContainer: {
     display: 'flex',
     flexDirection: 'row',
-    borderBottom: '1px solid #E0E0E0',
+    borderBottom: '1px solid var(--jp-border-color2)',
     padding: '8px 16px 8px 16px',
     fontSize: '9pt'
   },
@@ -20,14 +20,20 @@ const useStyles = createUseStyles({
     paddingRight: '8px'
   },
   listItemContent: {
+    display: 'flex',
+    flexDirection: 'column',
+    alignItems: 'stretch',
+    overflow: 'hidden',
     flex: 1
   },
   did: {
     textOverflow: 'ellipsis',
-    overflow: 'hidden'
+    overflow: 'hidden',
+    whiteSpace: 'nowrap'
   },
   variableName: {
-    color: '#808080'
+    overflowWrap: 'break-word',
+    color: 'var(--jp-ui-font-color2)'
   },
   statusIcon: {
     marginTop: '2px',
@@ -35,23 +41,24 @@ const useStyles = createUseStyles({
   },
   availableIcon: {
     extend: 'statusIcon',
-    color: '#5a9216'
+    color: 'var(--jp-success-color0)'
   },
   notAvailableIcon: {
     extend: 'statusIcon',
-    color: '#dd2c00'
+    color: 'var(--jp-error-color1)'
   },
   replicatingIcon: {
     extend: 'statusIcon',
-    color: '#ffa000'
+    color: 'var(--jp-rucio-yellow-color)'
   },
   pendingInjectionIcon: {
     extend: 'statusIcon',
-    color: '#a5d6a7'
+    color: 'var(--jp-success-color0)',
+    opacity: 0.5
   },
   notResolvedIcon: {
     extend: 'statusIcon',
-    color: '#e0e0e0'
+    color: 'var(--jp-ui-font-color2)'
   },
   actionContainer: {},
   clearButton: {
@@ -61,12 +68,18 @@ const useStyles = createUseStyles({
     cursor: 'pointer'
   },
   clearIcon: {
-    color: '#dd2c0090',
+    color: 'var(--jp-error-color1)',
+    opacity: 0.5,
     fontSize: '16px',
     lineHeight: '24px',
     '&:hover': {
-      color: '#dd2c00'
+      opacity: 1
     }
+  },
+  action: {
+    fontSize: '9pt',
+    color: 'var(--jp-rucio-primary-blue-color)',
+    cursor: 'pointer'
   }
 });
 
@@ -82,13 +95,13 @@ const _NotebookAttachmentListItem: React.FC<NotebookAttachmentListItemProps> = (
 
   const activeInstance = useStoreState(UIStore, s => s.activeInstance);
   const fileDetails = useStoreState(UIStore, s => s.fileDetails[did]);
-  const containerDetails = useStoreState(UIStore, s => s.containerDetails[did]);
+  const collectionDetails = useStoreState(UIStore, s => s.collectionDetails[did]);
 
   useEffect(() => {
     if (attachment.type === 'file') {
       actions.getFileDIDDetails(activeInstance.name, did);
     } else {
-      actions.getContainerDIDDetails(activeInstance.name, did);
+      actions.getCollectionDIDDetails(activeInstance.name, did);
     }
   }, []);
 
@@ -98,20 +111,44 @@ const _NotebookAttachmentListItem: React.FC<NotebookAttachmentListItemProps> = (
     });
   };
 
-  const containerState = useMemo(() => {
-    return containerDetails ? computeContainerState(containerDetails) : undefined;
-  }, [containerDetails]);
+  const collectionState = useMemo(() => {
+    return collectionDetails ? computeCollectionState(collectionDetails) : undefined;
+  }, [collectionDetails]);
+
+  const shouldDisplayMakeAvailableButton = (() => {
+    if (fileDetails) {
+      return fileDetails.status === 'STUCK' || fileDetails.status === 'NOT_AVAILABLE';
+    } else if (collectionState) {
+      return collectionState === 'STUCK' || collectionState === 'NOT_AVAILABLE' || collectionState === 'PARTIALLY_AVAILABLE';
+    }
+
+    return false;
+  })();
+
+  const makeAvailable = () => {
+    const { did, type } = attachment;
+    if (type === 'file') {
+      actions.makeFileAvailable(activeInstance.name, did);
+    } else {
+      actions.makeCollectionAvailable(activeInstance.name, did);
+    }
+  };
 
   return (
     <div className={classes.listItemContainer}>
       <div className={classes.listItemIconContainer}>
-        {!fileDetails && !containerDetails && <ResolverStatusIcon status={status} />}
+        {!fileDetails && !collectionDetails && <ResolverStatusIcon status={status} />}
         {!!fileDetails && <FileStatusIcon status={fileDetails.status} resolverStatus={status} />}
-        {!!containerState && <ContainerStatusIcon status={containerState} resolverStatus={status} />}
+        {!!collectionState && <CollectionStatusIcon status={collectionState} resolverStatus={status} />}
       </div>
       <div className={classes.listItemContent}>
         <div className={classes.did}>{attachment.did}</div>
         <div className={classes.variableName}>{attachment.variableName}</div>
+        {shouldDisplayMakeAvailableButton && (
+          <div className={classes.action} onClick={makeAvailable}>
+            Make Available
+          </div>
+        )}
       </div>
       <div className={classes.actionContainer}>
         <div className={classes.clearButton} onClick={deleteAttachment}>
@@ -153,7 +190,7 @@ const FileStatusIcon: React.FC<{ status: FileStatus; resolverStatus: ResolveStat
   }
 };
 
-const ContainerStatusIcon: React.FC<{ status: ContainerStatus; resolverStatus: ResolveStatus }> = ({
+const CollectionStatusIcon: React.FC<{ status: CollectionStatus; resolverStatus: ResolveStatus }> = ({
   status,
   resolverStatus
 }) => {
